@@ -1,5 +1,7 @@
-package Bread::Board::LazyLoader::Container;
-$Bread::Board::LazyLoader::Container::VERSION = '0.09';
+package # hide from PAUSE
+  Bread::Board::LazyLoader::Container;
+
+# DEPRECATED - use Bread::Board::LazyLoader qw(load_container)
 use Moose;
 
 # ABSTRACT: building subcontainers lazily
@@ -24,15 +26,15 @@ Bread::Board::LazyLoader::Container - building subcontainers lazily
 
 =head1 VERSION
 
-version 0.09
+version 0.11
 
 =head1 AUTHOR
 
-Roman Daniel <roman.daniel@davosro.cz>
+Roman Daniel <roman@daniel.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Roman Daniel.
+This software is copyright (c) 2016 by Roman Daniel.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
